@@ -18,9 +18,14 @@ class KeyAPISchema(BaseAPISchema):
         self_view_kwargs = {"id": "<id>"}
         self_view_many = "key_list"
 
+    store_id = fields.String(required=True)  # , load_only=True)
+
     name = fields.String(required=True)  # , load_only=True)
     description = fields.String(required=True)  # , load_only=True)
-    tags = fields.List(fields.Dict(keys=fields.String(required=True), values=fields.String()))
-    value_ids = fields.List(fields.String(required=True))  # , load_only=True)
+
+    # value_ids = fields.List(fields.String(required=True))  # , load_only=True)
     type = fields.String(required=True)  # , load_only=True)
+    encoding = fields.String(required=True)  # , load_only=True)
     expression = fields.String(required=False)  # , load_only=True)
+
+    tags = fields.List(fields.Dict(keys=fields.String(required=True), values=fields.String()))
