@@ -8,6 +8,7 @@ from datetime import datetime
 from mongoengine import Document, fields
 from sweetrpg_kv_objects.db.embedded.property.document import PropertyDocument
 from sweetrpg_kv_objects.db.embedded.tag.document import TagDocument
+from sweetrpg_kv_objects import constants
 
 
 class KeyDocument(Document):
@@ -24,13 +25,21 @@ class KeyDocument(Document):
         "strict": False,
     }
 
+    # references
+    store_id = fields.ReferenceField("StoreDocument")
+
     # basic properties
     name = fields.StringField(required=True)
-    type = fields.StringField(required=True)
     description = fields.StringField(required=True)
-    expression = fields.StringField()
+
+    type = fields.StringField(default=constants.KEY_TYPE_STRING, required=True)
+    encoding = fields.StringField(default=constants.KEY_ENCODING_PLAIN, required=True)
+    expression = fields.StringField(default="")
+
+    # other properties
     tags = fields.ListField(fields.EmbeddedDocumentField(TagDocument))
-    values = fields.ListField(fields.ReferenceField("ValueDocument"))
+
+    # values = fields.ListField(fields.ReferenceField("ValueDocument"))
 
     # audit properties
     created_at = fields.DateTimeField(default=datetime.utcnow, required=True)
