@@ -12,6 +12,9 @@ from sweetrpg_model_core.schema.base import BaseSchema
 class SnapshotSchema(BaseSchema):
     model_class = Snapshot
 
+    store_id = fields.String(required=True)  # , load_only=True)
+
     name = fields.String(required=True)  # , load_only=True)
+
     tags = fields.List(fields.Dict(keys=fields.String(required=True), values=fields.String()))
-    value_ids = fields.List(fields.String(required=True))  # , load_only=True)
+    # value_ids = fields.List(fields.String(required=True))  # , load_only=True)
