@@ -17,17 +17,22 @@ class ValueDocument(Document):
 
     meta = {
         "indexes": [
-            {"name": "value_key_snapshot", "fields": ["key", "snapshot"]},
+            {"name": "value_key_snapshot", "fields": ["key_id", "snapshot_id"]},
         ],
         "db_alias": "default",
         "collection": "values",
         "strict": False,
     }
 
+    # references
+    store_id = fields.ReferenceField("StoreDocument")
+    key_id = fields.ReferenceField("KeyDocument")
+    snapshot_id = fields.ReferenceField("SnapshotDocument")
+
     # basic properties
-    key = fields.ReferenceField("KeyDocument")
-    snapshot = fields.ReferenceField("SnapshotDocument")
     value = fields.StringField(required=True)
+
+    # other properties
     tags = fields.ListField(fields.EmbeddedDocumentField(TagDocument))
 
     # audit properties
